@@ -9,12 +9,12 @@
 
 #include <KToolTipWidget>
 
-#include <QLayout>
-#include <QStyle>
 #include <QLabel>
+#include <QLayout>
 #include <QLineEdit>
-#include <QSignalSpy>
 #include <QScreen>
+#include <QSignalSpy>
+#include <QStyle>
 #include <QTest>
 
 void KToolTipWidgetTest::initTestCase()
@@ -111,44 +111,47 @@ void KToolTipWidgetTest::shouldNotObscureTarget_data()
     QTest::addColumn<QPoint>("position");
     QTest::addColumn<QString>("content");
 
-    const QMap<QString,QPoint> positions{
-        {QStringLiteral("topleft"), QPoint(m_offset, m_offset)},
-        {QStringLiteral("topright"), QPoint(-m_offset, m_offset)},
-        {QStringLiteral("bottomright"), QPoint(-m_offset, -m_offset)},
-        {QStringLiteral("bottomleft"), QPoint(m_offset, -m_offset)},
-        {QStringLiteral("centered"),
-            QPoint(m_screenGeometry.width() / 2, m_screenGeometry.height() / 2)}
-    };
+    const QMap<QString, QPoint> positions{{QStringLiteral("topleft"), QPoint(m_offset, m_offset)},
+                                          {QStringLiteral("topright"), QPoint(-m_offset, m_offset)},
+                                          {QStringLiteral("bottomright"), QPoint(-m_offset, -m_offset)},
+                                          {QStringLiteral("bottomleft"), QPoint(m_offset, -m_offset)},
+                                          {QStringLiteral("centered"), QPoint(m_screenGeometry.width() / 2, m_screenGeometry.height() / 2)}};
 
     QMapIterator<QString, QPoint> i(positions);
     while (i.hasNext()) {
         i.next();
-        QTest::newRow(qPrintable(QStringLiteral("small/%1").arg(i.key())) )
-            << i.value()
-            << QStringLiteral("dummy text");
+        QTest::newRow(qPrintable(QStringLiteral("small/%1").arg(i.key()))) << i.value() << QStringLiteral("dummy text");
 
-        QTest::newRow(qPrintable(QStringLiteral("multiline/%1").arg(i.key())))
-            << i.value()
-            << QStringLiteral("dummy text\nLine 1\nLine 2\nLine 3");
+        QTest::newRow(qPrintable(QStringLiteral("multiline/%1").arg(i.key()))) << i.value() << QStringLiteral("dummy text\nLine 1\nLine 2\nLine 3");
 
         QTest::newRow(qPrintable(QStringLiteral("one long line/%1").arg(i.key())))
             << i.value()
             << QStringLiteral(
-                "Lorem ipsum dolor sit amet, consectetur adipiscing elit. Nullam nec felis sed elit auctor lobortis non a urna. Quisque non posuere mauris. Suspendisse potenti. In diam leo, lobortis at placerat nec, sagittis at tortor. Pellentesque scelerisque enim vel elementum scelerisque. Integer eget lectus vitae lorem pulvinar hendrerit. Suspendisse auctor sapien vel semper porta. Vestibulum fringilla aliquet tincidunt. Maecenas mollis mauris et erat viverra mollis. Proin suscipit felis nisi, a dapibus est hendrerit euismod. Suspendisse quis faucibus quam. Fusce eu cursus magna, et egestas purus. Duis enim sapien, feugiat id facilisis non, rhoncus ut lectus. Aliquam at nisi vel ligula interdum ultricies. Donec condimentum ante quam, eu congue lectus pulvinar in. Cras interdum, neque quis fermentum consequat, lectus tellus eleifend turpis."
-            );
+                   "Lorem ipsum dolor sit amet, consectetur adipiscing elit. Nullam nec felis sed elit auctor lobortis non a urna. Quisque non posuere mauris. "
+                   "Suspendisse potenti. In diam leo, lobortis at placerat nec, sagittis at tortor. Pellentesque scelerisque enim vel elementum scelerisque. "
+                   "Integer eget lectus vitae lorem pulvinar hendrerit. Suspendisse auctor sapien vel semper porta. Vestibulum fringilla aliquet tincidunt. "
+                   "Maecenas mollis mauris et erat viverra mollis. Proin suscipit felis nisi, a dapibus est hendrerit euismod. Suspendisse quis faucibus quam. "
+                   "Fusce eu cursus magna, et egestas purus. Duis enim sapien, feugiat id facilisis non, rhoncus ut lectus. Aliquam at nisi vel ligula "
+                   "interdum ultricies. Donec condimentum ante quam, eu congue lectus pulvinar in. Cras interdum, neque quis fermentum consequat, lectus "
+                   "tellus eleifend turpis.");
 
         if (m_screenGeometry.width() >= 1600 && m_screenGeometry.height() >= 900) {
             QTest::newRow(qPrintable(QStringLiteral("super large/%1").arg(i.key())))
                 << i.value()
                 << QStringLiteral(
-                    "dummy 0 text\nLine 1\nLine 2\nLine 3"
-                    "dummy 1 text\nLine 1\nLine 2\nLine 3"
-                    "dummy 2 text\nLine 1\nLine 2\nLine 3"
-                    "dummy 3 text\nLine 1\nLine 2\nLine 3"
-                    "dummy 4 text\nLine 1\nLine 2\nLine 3"
+                       "dummy 0 text\nLine 1\nLine 2\nLine 3"
+                       "dummy 1 text\nLine 1\nLine 2\nLine 3"
+                       "dummy 2 text\nLine 1\nLine 2\nLine 3"
+                       "dummy 3 text\nLine 1\nLine 2\nLine 3"
+                       "dummy 4 text\nLine 1\nLine 2\nLine 3"
 
-                    "Lorem ipsum dolor sit amet, consectetur adipiscing elit. Nullam nec felis sed elit auctor lobortis non a urna. Quisque non posuere mauris. Suspendisse potenti. In diam leo, lobortis at placerat nec, sagittis at tortor. Pellentesque scelerisque enim vel elementum scelerisque. Integer eget lectus vitae lorem pulvinar hendrerit. Suspendisse auctor sapien vel semper porta. Vestibulum fringilla aliquet tincidunt. Maecenas mollis mauris et erat viverra mollis. Proin suscipit felis nisi, a dapibus est hendrerit euismod. Suspendisse quis faucibus quam. Fusce eu cursus magna, et egestas purus. Duis enim sapien, feugiat id facilisis non, rhoncus ut lectus. Aliquam at nisi vel ligula interdum ultricies. Donec condimentum ante quam, eu congue lectus pulvinar in. Cras interdum, neque quis fermentum consequat, lectus tellus eleifend turpis."
-                );
+                       "Lorem ipsum dolor sit amet, consectetur adipiscing elit. Nullam nec felis sed elit auctor lobortis non a urna. Quisque non posuere "
+                       "mauris. Suspendisse potenti. In diam leo, lobortis at placerat nec, sagittis at tortor. Pellentesque scelerisque enim vel elementum "
+                       "scelerisque. Integer eget lectus vitae lorem pulvinar hendrerit. Suspendisse auctor sapien vel semper porta. Vestibulum fringilla "
+                       "aliquet tincidunt. Maecenas mollis mauris et erat viverra mollis. Proin suscipit felis nisi, a dapibus est hendrerit euismod. "
+                       "Suspendisse quis faucibus quam. Fusce eu cursus magna, et egestas purus. Duis enim sapien, feugiat id facilisis non, rhoncus ut "
+                       "lectus. Aliquam at nisi vel ligula interdum ultricies. Donec condimentum ante quam, eu congue lectus pulvinar in. Cras interdum, neque "
+                       "quis fermentum consequat, lectus tellus eleifend turpis.");
         }
     }
 }
@@ -158,21 +161,15 @@ void KToolTipWidgetTest::shouldNotObscureTarget()
     QFETCH(QPoint, position);
     QFETCH(QString, content);
 
-    QWidget* containerWidget = new QWidget();
+    QWidget *containerWidget = new QWidget();
     const int margin = containerWidget->style()->pixelMetric(QStyle::PM_ToolTipLabelFrameWidth);
-    QLabel* targetWidget = new QLabel(QStringLiteral("dummy file"));
-    QLayout* layout = new QHBoxLayout(containerWidget);
+    QLabel *targetWidget = new QLabel(QStringLiteral("dummy file"));
+    QLayout *layout = new QHBoxLayout(containerWidget);
     layout->addWidget(targetWidget);
 
     containerWidget->adjustSize();
-    containerWidget->move(
-        position.x() >= 0
-            ? position.x()
-            : m_screenGeometry.right() + position.x() - containerWidget->width(),
-        position.y() >= 0
-            ? position.y()
-            : m_screenGeometry.bottom() + position.y() - containerWidget->height()
-    );
+    containerWidget->move(position.x() >= 0 ? position.x() : m_screenGeometry.right() + position.x() - containerWidget->width(),
+                          position.y() >= 0 ? position.y() : m_screenGeometry.bottom() + position.y() - containerWidget->height());
     containerWidget->show();
     QVERIFY(QTest::qWaitForWindowExposed(containerWidget));
     QVERIFY(targetWidget->isVisible());
@@ -180,7 +177,7 @@ void KToolTipWidgetTest::shouldNotObscureTarget()
     QRect targetRect = QRect(targetWidget->frameGeometry());
     targetRect.moveTo(targetWidget->mapToGlobal(QPoint(0, 0)));
 
-    QLabel* contentWidget = new QLabel(content);
+    QLabel *contentWidget = new QLabel(content);
 
     QVERIFY2(containerWidget->windowHandle(), "Container's window handle is invalid");
     KToolTipWidget tooltipWidget;
@@ -188,28 +185,20 @@ void KToolTipWidgetTest::shouldNotObscureTarget()
     QVERIFY(QTest::qWaitForWindowExposed(&tooltipWidget));
     const QRect tooltipRect = tooltipWidget.frameGeometry();
 
-    qDebug() << QStringLiteral("tooltip: %1x%2 x=%3, y=%4")
-        .arg(tooltipRect.width())
-        .arg(tooltipRect.height())
-        .arg(tooltipRect.left())
-        .arg(tooltipRect.top());
-    qDebug() << QStringLiteral("target:  %1x%2 x=%3, y=%4")
-        .arg(targetRect.width())
-        .arg(targetRect.height())
-        .arg(targetRect.left())
-        .arg(targetRect.top());
+    qDebug() << QStringLiteral("tooltip: %1x%2 x=%3, y=%4").arg(tooltipRect.width()).arg(tooltipRect.height()).arg(tooltipRect.left()).arg(tooltipRect.top());
+    qDebug() << QStringLiteral("target:  %1x%2 x=%3, y=%4").arg(targetRect.width()).arg(targetRect.height()).arg(targetRect.left()).arg(targetRect.top());
 
     QVERIFY2(!tooltipRect.intersects(targetRect), "Target obscured");
     QCOMPARE(tooltipRect.intersected(m_screenGeometry), tooltipRect);
 
     // Check margins
-    if (tooltipRect.bottom() <  targetRect.top()) {
+    if (tooltipRect.bottom() < targetRect.top()) {
         QCOMPARE(margin, targetRect.top() - tooltipRect.bottom());
     } else if (tooltipRect.top() > targetRect.bottom()) {
         QCOMPARE(margin, tooltipRect.top() - targetRect.bottom());
     } else if (tooltipRect.right() < targetRect.left()) {
         QCOMPARE(margin, targetRect.left() - tooltipRect.right());
-    } else if (tooltipRect.left() > targetRect.right() ) {
+    } else if (tooltipRect.left() > targetRect.right()) {
         QCOMPARE(margin, tooltipRect.left() - targetRect.right());
     }
 
@@ -220,7 +209,6 @@ void KToolTipWidgetTest::shouldNotObscureTarget()
     delete containerWidget;
 }
 
-
 QTEST_MAIN(KToolTipWidgetTest)
 
-
+#include "moc_ktooltipwidgettest.cpp"
