@@ -23,7 +23,7 @@ public:
         animation.setDuration(2000);
         animation.setStartValue(0);
         animation.setEndValue(360);
-        QObject::connect(&animation, &QVariantAnimation::valueChanged, q, [=](QVariant value) {
+        QObject::connect(&animation, &QVariantAnimation::valueChanged, q, [this](QVariant value) {
             rotation = value.toReal();
             q->update(); // repaint new rotation
         });
@@ -89,3 +89,5 @@ bool KBusyIndicatorWidget::event(QEvent *event)
     // the vtable or not.
     return QWidget::event(event);
 }
+
+#include "moc_kbusyindicatorwidget.cpp"
